summaryrefslogtreecommitdiffstats
path: root/experimental/tqtinterface/qt4/src/kernel/tqregion_x11.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'experimental/tqtinterface/qt4/src/kernel/tqregion_x11.cpp')
-rw-r--r--experimental/tqtinterface/qt4/src/kernel/tqregion_x11.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/experimental/tqtinterface/qt4/src/kernel/tqregion_x11.cpp b/experimental/tqtinterface/qt4/src/kernel/tqregion_x11.cpp
index 4e573c92d..ddc80a086 100644
--- a/experimental/tqtinterface/qt4/src/kernel/tqregion_x11.cpp
+++ b/experimental/tqtinterface/qt4/src/kernel/tqregion_x11.cpp
@@ -563,7 +563,7 @@ miCoalesce (register TQRegionPrivate *pReg, int prevStart, int curStart)
if (pCurBox != pRegEnd)
{
/*
- * If more than one band was added, we have to tqfind the start
+ * If more than one band was added, we have to find the start
* of the last band added so the next coalescing job can start
* at the right place... (given when multiple bands are added,
* this may be pointless -- see above).
@@ -1494,7 +1494,7 @@ SOFTWARE.
************************************************************************/
/*
* This file tqcontains a few macros to help track
* the edge of a filled object. The object is assumed
* to be filled in scanline order, and thus the
* algorithm used is an extension of Bresenham's line
@@ -1578,7 +1578,7 @@ SOFTWARE.
/*
* This structure tqcontains all of the information needed
* to run the bresenham algorithm.
* The variables may be hardcoded into the declarations
* instead of using this structure to make use of
@@ -1799,8 +1799,8 @@ SOFTWARE.
* InsertEdgeInET
*
* Insert the given edge into the edge table.
- * First we must tqfind the correct bucket in the
- * Edge table, then tqfind the right slot in the
+ * First we must find the correct bucket in the
+ * Edge table, then find the right slot in the
* bucket. Finally, we can insert it.
*
*/
@@ -1813,7 +1813,7 @@ InsertEdgeInET(EdgeTable *ET, EdgeTableEntry *ETE, int scanline,
ScanLineListBlock *tmpSLLBlock;
/*
- * tqfind the right bucket to put the edge into
+ * find the right bucket to put the edge into
*/
pPrevSLL = &ET->scanlines;
pSLL = pPrevSLL->next;
@@ -1928,7 +1928,7 @@ CreateETandAET(register int count, register TQPoint *pts,
CurrPt = pts++;
/*
- * tqfind out which point is above and which is below.
+ * find out which point is above and which is below.
*/
if (PrevPt->y() > CurrPt->y() )
{
@@ -2643,7 +2643,7 @@ bool TQRegion::isNull() const
/*!
Returns TRUE if the region is empty; otherwise returns FALSE. An
- empty region is a region that tqcontains no points.
+ empty region is a region that contains no points.
Example:
\code
@@ -2672,11 +2672,11 @@ bool TQRegion::isEmpty() const
/*!
- Returns TRUE if the region tqcontains the point \a p; otherwise
+ Returns TRUE if the region contains the point \a p; otherwise
returns FALSE.
*/
-bool TQRegion::tqcontains( const TQPoint &p ) const
+bool TQRegion::contains( const TQPoint &p ) const
{
return PointInRegion( data->region, p.x(), p.y() );
}
@@ -2688,7 +2688,7 @@ bool TQRegion::tqcontains( const TQPoint &p ) const
returns FALSE.
*/
-bool TQRegion::tqcontains( const TQRect &r ) const
+bool TQRegion::contains( const TQRect &r ) const
{
return RectInRegion( data->region, r.left(), r.top(),
r.width(), r.height() ) != RectangleOut;
@@ -1494,7 +1494,7 @@ SOFTWARE.
************************************************************************/
/*
- * This file tqcontains a few macros to help track
+ * This file contains a few macros to help track
* the edge of a filled object. The object is assumed
* to be filled in scanline order, and thus the
@@ -1578,7 +1578,7 @@ SOFTWARE.
/*
- * This structure tqcontains all of the information needed
+ * This structure contains all of the information needed
* to run the bresenham algorithm.
* The variables may be hardcoded into the declarations